@@ -5,8 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Package-Version: 1.12
-;; Package-Revision: 1.12-0-g9bbc44cc7e08
+;; Version: 1.12
 ;; Package-Requires: ((emacs "29.1") (org "9.6") (compat "30"))
 ;; URL: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, text
@@ -366,9 +365,8 @@ the font.")
   "Face used for inactive time labels.")
 
 (defface org-modern-horizontal-rule
-  '((default :inherit org-hide)
-    (((background light)) :strike-through "gray70")
-    (t :strike-through "gray30"))
+  '((((background light)) :underline "gray70" :extend t)
+    (t :underline "gray30" :extend t))
   "Face used for horizontal ruler.")
 
 (defvar-local org-modern--font-lock-keywords nil)
@@ -740,11 +738,11 @@ whole buffer; otherwise, for the line at point."
                 ''(face nil invisible org-modern)
               '(org-modern--star))))))
    (when org-modern-horizontal-rule
-     `(("^[ \t]*-\\{5,\\}$" 0
-        '(face org-modern-horizontal-rule display
-               ,(if (eq org-modern-horizontal-rule t)
-                    '(space :width (- text 1))
-                  org-modern-horizontal-rule)))))
+     `(("\\(^[ \t]*-\\{5,\\}\\)\r?\n"
+        ,@(if (stringp org-modern-horizontal-rule)
+              `(1 '(face nil display ,org-modern-horizontal-rule))
+            '((1 '(face nil display " "))
+              (0 '(face org-modern-horizontal-rule)))))))
    (when org-modern-table
      '(("^[ \t]*\\(|.*|\\)[ \t]*$" (0 (org-modern--table)))))
    (when org-modern-footnote
